<?php
/**
 * Register post type and meta boxes
 *
 * @link       https://walterpinem.me/
 * @since      1.0.0
 *
 * @package    Wp_Mylinks
 * @subpackage Wp_Mylinks/includes
 * @author     Walter Pinem <hello@walterpinem.me>
 */
// Register Custom Post Type for MyLink
function wp_mylinks_register_post_type() {
	$labels = array(
		'name' 						=> _x( 'MyLinks', 'Post Type General Name', 'wp-mylinks' ),
		'singular_name' 			=> _x( 'MyLink', 'Post Type Singular Name', 'wp-mylinks' ),
		'menu_name' 				=> _x( 'MyLinks', 'Admin Menu text', 'wp-mylinks' ),
		'name_admin_bar' 			=> _x( 'MyLink', 'Add New on Toolbar', 'wp-mylinks' ),
		'archives' 					=> __( 'MyLink Archives', 'wp-mylinks' ),
		'attributes' 				=> __( 'MyLink Attributes', 'wp-mylinks' ),
		'parent_item_colon' 		=> __( 'Parent MyLink:', 'wp-mylinks' ),
		'all_items' 				=> __( 'All MyLinks', 'wp-mylinks' ),
		'add_new_item' 				=> __( 'Add New MyLink', 'wp-mylinks' ),
		'add_new' 					=> __( 'Add New', 'wp-mylinks' ),
		'new_item' 					=> __( 'New MyLink', 'wp-mylinks' ),
		'edit_item' 				=> __( 'Edit MyLink', 'wp-mylinks' ),
		'update_item' 				=> __( 'Update MyLink', 'wp-mylinks' ),
		'view_item' 				=> __( 'View MyLink', 'wp-mylinks' ),
		'view_items' 				=> __( 'View MyLinks', 'wp-mylinks' ),
		'search_items' 				=> __( 'Search MyLink', 'wp-mylinks' ),
		'not_found' 				=> __( 'Not found', 'wp-mylinks' ),
		'not_found_in_trash' 		=> __( 'Not found in Trash', 'wp-mylinks' ),
		'featured_image' 			=> __( 'Featured Image', 'wp-mylinks' ),
		'set_featured_image' 		=> __( 'Featured Image', 'wp-mylinks' ),
		'remove_featured_image' 	=> __( 'Remove featured image', 'wp-mylinks' ),
		'use_featured_image' 		=> __( 'Use as featured image', 'wp-mylinks' ),
		'insert_into_item' 			=> __( 'Insert into MyLink', 'wp-mylinks' ),
		'uploaded_to_this_item' 	=> __( 'Uploaded to this MyLink', 'wp-mylinks' ),
		'items_list' 				=> __( 'MyLinks list', 'wp-mylinks' ),
		'items_list_navigation' 	=> __( 'MyLinks list navigation', 'wp-mylinks' ),
		'filter_items_list' 		=> __( 'Filter MyLinks list', 'wp-mylinks' ),
		'register_meta_box_cb' 		=> 'wp_mylinks_register_metabox',
	);
	$rewrite = array(
		'slug' 			=> '/',
		'with_front' 	=> false,
		'pages' 		=> false,
		'feeds' 		=> false,
	);
	$args = array(
		'label' 				=> __( 'MyLink', 'wp-mylinks' ),
		'description' 			=> __( 'Create micro landing pages that host all of your contents, products, etc to engage your audience and increase your brand awareness.', 'wp-mylinks' ),
		'labels' 				=> $labels,
		'menu_icon' 			=> 'dashicons-editor-unlink',
		'supports' 				=> array('title'),
		'taxonomies' 			=> array(),
		'public' 				=> true,
		'show_ui' 				=> true,
		'show_in_menu' 			=> true,
		'menu_position' 		=> 26,
		'show_in_admin_bar' 	=> false,
		'show_in_nav_menus' 	=> true,
		'can_export' 			=> true,
		'has_archive' 			=> false,
		'hierarchical' 			=> false,
		'exclude_from_search' 	=> true,
		'show_in_rest' 			=> true,
		'query_var' 			=> 'mylink',
		'publicly_queryable' 	=> true,
		'capability_type' 		=> 'page',
		'rewrite' 				=> $rewrite,
	);
	register_post_type( 'mylink', $args );
	flush_rewrite_rules( false );
}
add_action( 'init', 'wp_mylinks_register_post_type', 0 );

// Generate Metabox for MyLink post type
add_action( 'cmb2_admin_init', 'wp_mylinks_register_cmb2_metaboxes' );
/**
* Define the metabox and field configurations.
*/
function wp_mylinks_register_cmb2_metaboxes() {
	$cmb = new_cmb2_box(
		[
			'id'           => mylinks_prefix( 'form' ),
			'title'        => __( 'MyLinks Profile', 'wp-mylinks' ),
			'object_types' => [ 'mylink' ],
			'context'      => 'normal',
			'priority'     => 'high',
		]
	);
	$cmb->add_field(
		[
			'name'         => __( 'Avatar', 'wp-mylinks' ),
			'desc'         => __( 'Upload an avatar, preferably square in size.', 'wp-mylinks' ),
			'id'           => mylinks_prefix( 'avatar' ),
			'type'         => 'file',
			'before_row'   => __('Build a profile section for your MyLinks page.', 'wp-mylinks'),
			'options'      => [
					'url'  => false, // Hide the text input for the url
				],
				'text'         => [
					'add_upload_file_text' => 'Choose Avatar',
				],
				'query_args'   => [
					'type' => 'image',
				],
				'preview_size' => 'thumbnail',
			]
		);
	$cmb->add_field(
		[
			'name'    => __( 'Name', 'wp-mylinks' ),
			'desc'    => __( 'Add your name or username that will be shown under your avatar.', 'wp-mylinks' ),
			'id'      => mylinks_prefix( 'name' ),
			'type'    => 'text',
			'attributes'  => array(
				'class' => 'mylinks-input-text',
			),
			'options' => [],
		]
	);
	$cmb->add_field(
		[
			'name'    => __( 'Description', 'wp-mylinks' ),
			'desc'    => __( 'Add your profile description that will be shown under your name. Compatible with HTML.', 'wp-mylinks' ),
			'id'      => mylinks_prefix( 'description' ),
			'type'    => 'textarea_small',
			'attributes'  => array(
				'class' => 'mylinks-input-textarea',
			),
			'options' => [],
		]
	);
	$cmb->add_field( 
		[
			'name'             => __( 'Theme', 'wp-mylinks' ),
			'desc'    		   => __( 'Choose a theme that matches your personal or business brand.', 'wp-mylinks' ),
			'id'               => mylinks_prefix( 'theme' ),
			'before_row'   	   => __('Determine how you want the MyLinks page to look like. You can set its theme individually here or select <code>None</code>to<br> apply global theme you set on <a href="edit.php?post_type=mylink&page=welcome&tab=global" target="_blank"><strong>Global Configurations</strong></a> page instead.', 'wp-mylinks' ),
			'type'             => 'select',
			'show_option_none' => false,
			'default'          => 'default',
			'attributes'  	   => array(
				'class' 	   => 'mylinks-input-select',
			),
			'options_cb'       => 'wp_mylinks_theme_callback',
		]
	);

	// Social Media Profiles
	$cmb = new_cmb2_box(
		[
			'id'           => mylinks_prefix( 'form-social' ),
			'title'        => __( 'Social Media', 'wp-mylinks' ),
			'object_types' => [ 'mylink' ],
			'context'      => 'normal',
			'priority'     => 'high',
		]
	);
	// Facebook
	$cmb->add_field(
		[
			'name'    => __( 'Facebook URL', 'wp-mylinks' ),
			'desc'    => __( 'Add your Facebook profile.', 'wp-mylinks' ),
			'id'      => mylinks_prefix( 'facebook-url' ),
			'type'    => 'text_url',
			'before_row'   => __('Setup social links that will appear under your profile section.', 'wp-mylinks' ),
			'attributes'  => array(
				'class' => 'mylinks-input-url',
			),
			'options' => [],
		]
	);
	$cmb->add_field(
		[
			'name'         => __( 'Facebook Icon', 'wp-mylinks' ),
			'desc'         => __( 'If you don\'t like the default icon please upload your own icon for Facebook, preferably square in size.', 'wp-mylinks' ),
			'id'           => mylinks_prefix( 'facebook-icon' ),
			'type'         => 'file',
			'options'      => [
					'url'  => true, // Hide the text input for the url
				],
				'text'	   => [
					'add_upload_file_text' => 'Choose Icon',
				],
				'query_args'   => [
					'type' => 'image',
				],
				'preview_size' => 'thumbnail',
			]
		);
	// Twitter
	$cmb->add_field(
		[
			'name'    => __( 'Twitter URL', 'wp-mylinks' ),
			'desc'    => __( 'Add your Twitter profile.', 'wp-mylinks' ),
			'id'      => mylinks_prefix( 'twitter-url' ),
			'type'    => 'text_url',
			'attributes'  => array(
				'class' => 'mylinks-input-url',
			),
			'options' => [],
		]
	);
	$cmb->add_field(
		[
			'name'         => __( 'Twitter Icon', 'wp-mylinks' ),
			'desc'         => __( 'If you don\'t like the default icon please upload your own icon for Twitter, preferably square in size.', 'wp-mylinks' ),
			'id'           => mylinks_prefix( 'twitter-icon' ),
			'type'         => 'file',
			'options'      => [
					'url'  => true, // Hide the text input for the url
				],
				'text'         => [
					'add_upload_file_text' => 'Choose Icon',
				],
				'query_args'   => [
					'type' => 'image',
				],
				'preview_size' => 'thumbnail',
			]
		);
	// Linkedin
	$cmb->add_field(
		[
			'name'    => __( 'Linkedin URL', 'wp-mylinks' ),
			'desc'    => __( 'Add your Linkedin profile.', 'wp-mylinks' ),
			'id'      => mylinks_prefix( 'linkedin-url' ),
			'type'    => 'text_url',
			'attributes'  => array(
				'class' => 'mylinks-input-url',
			),
			'options' => [],
		]
	);
	$cmb->add_field(
		[
			'name'         => __( 'Linkedin Icon', 'wp-mylinks' ),
			'desc'         => __( 'If you don\'t like the default icon please upload your own icon for Linkedin, preferably square in size.', 'wp-mylinks' ),
			'id'           => mylinks_prefix( 'linkedin-icon' ),
			'type'         => 'file',
			'options'      => [
					'url'  => true, // Hide the text input for the url
				],
				'text'	   => [
					'add_upload_file_text' => 'Choose Icon',
				],
				'query_args'   => [
					'type' => 'image',
				],
				'preview_size' => 'thumbnail',
			]
		);
	// Instagram
	$cmb->add_field(
		[
			'name'    => __( 'Instagram URL', 'wp-mylinks' ),
			'desc'    => __( 'Add your Instagram profile.', 'wp-mylinks' ),
			'id'      => mylinks_prefix( 'instagram-url' ),
			'type'    => 'text_url',
			'attributes'  => array(
				'class' => 'mylinks-input-url',
			),
			'options' => [],
		]
	);
	$cmb->add_field(
		[
			'name'         	=> __( 'Instagram Icon', 'wp-mylinks' ),
			'desc'         	=> __( 'If you don\'t like the default icon please upload your own icon for Instagram, preferably square in size.', 'wp-mylinks' ),
			'id'           	=> mylinks_prefix( 'instagram-icon' ),
			'type'         	=> 'file',
			'options'      	=> [
					'url'	=> true, // Hide the text input for the url
				],
				'text'		=> [
					'add_upload_file_text' => 'Choose Icon',
				],
				'query_args'   	=> [
					'type'	   	=> 'image',
				],
				'preview_size' 	=> 'thumbnail',
			]
		);
	// Youtube
	$cmb->add_field(
		[
			'name'    => __( 'Youtube URL', 'wp-mylinks' ),
			'desc'    => __( 'Add your Youtube profile.', 'wp-mylinks' ),
			'id'      => mylinks_prefix( 'youtube-url' ),
			'type'    => 'text_url',
			'attributes'  => array(
				'class' => 'mylinks-input-url',
			),
			'options' => [],
		]
	);
	$cmb->add_field(
		[
			'name'         	=> __( 'Youtube Icon', 'wp-mylinks' ),
			'desc'         	=> __( 'If you don\'t like the default icon please upload your own icon for Youtube, preferably square in size.', 'wp-mylinks' ),
			'id'           	=> mylinks_prefix( 'youtube-icon' ),
			'type'         	=> 'file',
			'options'      	=> [
					'url' 		=> true, // Hide the text input for the url
				],
				'text'         	=> [
					'add_upload_file_text' => 'Choose Icon',
				],
				'query_args'   	=> [
					'type' 		=> 'image',
				],
				'preview_size' => 'thumbnail',
			]
		);
	// TikTok
	$cmb->add_field(
		[
			'name'    => __( 'TikTok URL', 'wp-mylinks' ),
			'desc'    => __( 'Add your TikTok profile.', 'wp-mylinks' ),
			'id'      => mylinks_prefix( 'tiktok-url' ),
			'type'    => 'text_url',
			'attributes'  => array(
				'class' => 'mylinks-input-url',
			),
			'options' => [],
		]
	);
	$cmb->add_field(
		[
			'name'         => __( 'TikTok Icon', 'wp-mylinks' ),
			'desc'         => __( 'If you don\'t like the default icon please upload your own icon for TikTok, preferably square in size.', 'wp-mylinks' ),
			'id'           => mylinks_prefix( 'tiktok-icon' ),
			'type'         => 'file',
			'options'      => [
					'url'  => true, // Hide the text input for the url
				],
				'text'         => [
					'add_upload_file_text' => 'Choose Icon',
				],
				'query_args'   => [
					'type' => 'image',
				],
				'preview_size' => 'thumbnail',
			]
		);
	// END - Social Media Profiles

	// Links
	$cmb = new_cmb2_box(
		[
			'id'           => mylinks_prefix( 'form-links' ),
			'title'        => __( 'Links', 'wp-mylinks' ),
			'object_types' => [ 'mylink' ],
			'context'      => 'normal',
			'priority'     => 'high',
		]
	);
	$links_group = $cmb->add_field(
		[
			'id'          		=> mylinks_prefix( 'links' ),
			'type'        		=> 'group',
			'description' 		=> __( 'Set a link and its title. You can add unlimited number of buttons to your liking by clicking "Add Another Link" button.', 'wp-mylinks' ),
			'options'     		=> [
					'group_title'   => __( 'Link {#}', 'wp-mylinks' ),
					'add_button'    => __( 'Add Another Link', 'wp-mylinks' ),
					'remove_button' => __( 'Remove Link', 'wp-mylinks' ),
					'sortable'      => true,
				],
			]
		);
	$cmb->add_group_field(
		$links_group,
		[
			'name' => __( 'Title', 'wp-mylinks' ),
			'id'   => 'title',
			'type' => 'text',
			'attributes'  => array(
				'class' => 'mylinks-input-text',
			),
		]
	);
	$cmb->add_group_field(
		$links_group,
		[
			'name' => __( 'Link URL', 'wp-mylinks' ),
			'id'   => 'url',
			'type' => 'text_url',
			'attributes'  => array(
				'class' => 'mylinks-input-url',
			),
		]
	);
	$cmb->add_group_field(
		$links_group,
		[
			'name' 			=> __( 'Image', 'wp-mylinks' ),
			'id'   			=> 'image',
			'type' 			=> 'file',
			'preview_size' 	=> 'thumbnail',
			'description' 	=> __( 'Add featured image for your link, preferably square in size.', 'wp-mylinks' ),
			'options' => array(
				'add_upload_file_text' => __( 'Featured Image', 'wp-mylinks' ),
			),
		]
	);

	// Meta Tags
	$cmb = new_cmb2_box(
		[
			'id'           => mylinks_prefix( 'form-meta-tags' ),
			'title'        => __( 'Setup Meta Tags', 'wp-mylinks' ),
			'description'    => __( 'If you use Yoast SEO, set the meta title on Yoast\'s meta box instead.', 'wp-mylinks' ),
			'object_types' => [ 'mylink' ],
			'context'      => 'normal',
			'priority'     => 'high',
		]
	);
	$cmb->add_field(
		[
			'name'    => __( 'Meta Title', 'wp-mylinks' ),
			'desc'    => __( 'Set the meta title for this page.', 'wp-mylinks' ),
			'id'      => mylinks_prefix( 'meta-title' ),
			'type'    => 'text',
			'before_row'   => __('If you use Yoast SEO, you can set the meta tags on Yoast SEO\'s meta box. Or you can also set global meta tags on<br> <a href="edit.php?post_type=mylink&page=welcome&tab=global" target="_blank"><strong>Global Configurations</strong></a>.', 'wp-mylinks'),
			'attributes'  => array(
				'class' => 'mylinks-input-text',
			),
			'options' => [],
		]
	);
	$cmb->add_field(
		[
			'name'    => __( 'Meta Description', 'wp-mylinks' ),
			'desc'    => __( 'Set the meta description for this page.', 'wp-mylinks' ),
			'id'      => mylinks_prefix( 'meta-description' ),
			'type'    => 'textarea_small',
			'attributes'  => array(
				'class' => 'mylinks-input-textarea',
			),
			'options' => [],
		]
	);
	$cmb->add_field(
		[
			'name'    => __( 'Set to Noindex?', 'wp-mylinks' ),
			'desc'    => __( 'This will prevent MyLinks page from being indexed on search engine.', 'wp-mylinks' ),
			'id'      => mylinks_prefix( 'noindex' ),
			'type'             => 'radio',
			'show_option_none' => false,
			'options'          => array(
				'yes' => __( 'Yes', 'wp-mylinks' ),
				'no'   => __( 'No', 'wp-mylinks' ),
			),
		]
	);
	$cmb->add_field(
		[
			'name'    => __( 'Set to Nofollow?', 'wp-mylinks' ),
			'desc'    => __( 'This will ban crawlers to follow all the links on the MyLinks page.', 'wp-mylinks' ),
			'id'      => mylinks_prefix( 'nofollow' ),
			'type'             => 'radio',
			'show_option_none' => false,
			'options'          => array(
				'yes' => __( 'Yes', 'wp-mylinks' ),
				'no'   => __( 'No', 'wp-mylinks' ),
			),
		]
	);
}
