<?php
/**
 *
 * @link              https://walterpinem.me/
 * @since             1.0.0
 * @package           Wp_Mylinks
 * @copyright  		  Copyright (c) 2020, Walter Pinem, Seni Berpikir
 * 
 * @wordpress-plugin
 * Plugin Name:       WP MyLinks
 * Plugin URI:        https://walterpinem.me/projects/
 * Description:       Easily build your own micro landing page showing all the links you want to share to engage your audience. Use your own brand, link it anywhere.
 * Version:           1.0.0
 * Author:            Walter Pinem
 * Author URI:        https://walterpinem.me/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       wp-mylinks
 * Domain Path:       /languages
 */
// If this file is called directly, abort.
if (!defined('WPINC')) {
	die;
}
/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define('WP_MYLINKS_VERSION', '1.0.0');
define('WP_MYLINKS_PREFIX', 'mylinks_');
function mylinks_prefix($key) {
	return 'mylinks_' . $key;
}
/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-wp-mylinks-activator.php
 */
function activate_wp_mylinks() {
	require_once plugin_dir_path(__FILE__) . 'includes/class-wp-mylinks-activator.php';
	Wp_Mylinks_Activator::activate();
}
/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-wp-mylinks-deactivator.php
 */
function deactivate_wp_mylinks() {
	require_once plugin_dir_path(__FILE__) . 'includes/class-wp-mylinks-deactivator.php';
	Wp_Mylinks_Deactivator::deactivate();
}
register_activation_hook(__FILE__, 'activate_wp_mylinks');
register_deactivation_hook(__FILE__, 'deactivate_wp_mylinks');
/**
 * The core plugin classes that are used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path(__FILE__) . 'includes/class-wp-mylinks.php';
require plugin_dir_path(__FILE__) . 'admin/partials/wp-mylinks-admin-settings.php';
require plugin_dir_path(__FILE__) . 'includes/class-wp-mylinks-post-type.php';

/* Load base template for the landing page */
add_filter('single_template', 'wp_mylinks_template');
function wp_mylinks_template($single) {
	global $post;
/* Checks for single template by post type */
	if ($post->post_type == 'mylink') {
		if (file_exists(plugin_dir_path(__FILE__) . 'public/partials/wp-mylinks-base-template.php')) {
			return plugin_dir_path(__FILE__) . 'public/partials/wp-mylinks-base-template.php';
		}
	}
	return $single;
}
/**
 * Register the main public CSS
 */
function wp_mylinks_register_style() {
    wp_register_style( 'mylinks-public-css', plugin_dir_url(__FILE__).'public/css/wp-mylinks-public.min.css' );
}
add_action( 'init', 'wp_mylinks_register_style' );
/**
 * Including the CMB2 init.php file
 */
if (file_exists(plugin_dir_path(__FILE__) . 'includes/cmb2/init.php')) {
	require_once plugin_dir_path(__FILE__) . 'includes/cmb2/init.php';
}
/**
 * Get mylink
 *
 */
function wp_mylinks_is_queried() {
	return ('mylink' === get_post_type());
}
/**
 * Check if Yoast SEO / Premium is active
 *
 */
function wp_mylinks_isYoastActive() {
	$active_plugins = apply_filters('active_plugins', get_option('active_plugins'));
	foreach ($active_plugins as $plugin) {
		if (strpos($plugin, 'wp-seo')) {
			return true;
		}
	}
	return false;
}
/**
 * Track Visited MyLinks Page(s)
 *
 */
if (!function_exists('wp_mylinks_track_mylink_page')):
/**
* Get the view counts
*/
	function wp_mylinks_track_mylink_page($postID) {
		$count_key = 'wp_mylinks_count_visits';
		$count = get_post_meta($postID, $count_key, true);
		if ($count == '') {
			$count = 1;
			delete_post_meta($postID, $count_key);
			add_post_meta($postID, $count_key, '1');
		} else {
			$count++;
			update_post_meta($postID, $count_key, $count);
		}
	}
endif;
/**
 * Add setting link plugin page
 *
 */
function wp_mylinks_settings_link( $links_array, $plugin_file_name ){
  if( strpos( $plugin_file_name, basename(__FILE__) ) ) {
    array_unshift( $links_array, '<a href="edit.php?post_type=mylink&page=welcome">Settings</a>' );
    }
  return $links_array;
}
add_filter( 'plugin_action_links', 'wp_mylinks_settings_link', 10, 2 );
/**
 * Callback function for theme options meta box
 *
 */
function wp_mylinks_theme_callback() {
    // return a standard options array
    return array(
    	'none'     		=> __( 'None', 'wp-mylinks' ),
    	'default'      	=> __( 'Default', 'wp-mylinks' ),
    	'merbabu'		=> __( 'Merbabu', 'wp-mylinks' ),
    	'cikuray' 		=> __( 'Cikuray', 'wp-mylinks' ),
    	'ciremai' 		=> __( 'Ciremai', 'wp-mylinks' ),
    	'slamet'  		=> __( 'Slamet', 'wp-mylinks' ),
    	'papandayan' 	=> __( 'Papandayan', 'wp-mylinks' ),
    	'sindoro' 		=> __( 'Sindoro', 'wp-mylinks' ),
    	'krakatau' 		=> __( 'Krakatau', 'wp-mylinks' ),
    	'bromo' 		=> __( 'Bromo', 'wp-mylinks' ),
    	'prau' 			=> __( 'Prau', 'wp-mylinks' ),
    	'polos' 		=> __( 'Polos', 'wp-mylinks' ),
    	'datar' 		=> __( 'Datar', 'wp-mylinks' ),
    	'pastel' 		=> __( 'Pastel', 'wp-mylinks' ),
    	'kopi-hitam' 	=> __( 'Kopi Hitam', 'wp-mylinks' ),
    	'kopi-susu' 	=> __( 'Kopi Susu', 'wp-mylinks' ),
    );
}
/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_wp_mylinks() {
	$plugin = new Wp_Mylinks();
	$plugin->run();
}
run_wp_mylinks();